:github_url:

.. _api:

API
===

The application programming interface (API) is one of two modes of usage, next to *scherbelberg*'s :ref:`CLI <cli>`.

.. toctree::
   :maxdepth: 2
   :caption: The API in detail

   cluster
   command
   process
   node
   sshconfig
